@@ -17,11 +17,11 @@ xinc_home = os.environ.get('XINC_HOME')
 
 def _check_xinc():
     if not xinc_home:
-        LOG.error('$XINC_HOME not set')
+        LOG.debug('$XINC_HOME not set')
         return False
 
     if not os.path.exists(xinc_home):
-        LOG.error('$XINC_HOME=%s does not exist' % xinc_home)
+        LOG.debug('$XINC_HOME=%s does not exist' % xinc_home)
         return False
 
     return True        
