@@ -64,7 +64,7 @@ class HTML2FOConverter(object):
 
     implements(IHTML2FOConverter)
 
-    def convert(self, filename, encoding='utf-8', language='en', country='en', tidy=True):
+    def convert(self, filename, encoding='utf-8', tidy=True, **kw):
         """ Convert a HTML file stored as 'filename' to
             FO using CSS2XSLFO.
         """
@@ -78,7 +78,11 @@ class HTML2FOConverter(object):
             raise IOError('%s does not exist' % csstoxslfo)
 
         cmd = '"%s"' % java + \
-              ' -Duser.language=en -Xms128m -Xmx128m -jar "%(csstoxslfo)s" "%(filename)s" -fo "%(fo_filename)s" country=%(country)s language=%(language)s' % vars()
+              ' -Duser.language=en -Xms128m -Xmx128m -jar "%(csstoxslfo)s" "%(filename)s" -fo "%(fo_filename)s"' % vars()
+
+        for k in kw:
+            cmd += ' %s="%s"' % (k, kw[k])
+
         status, output = runcmd(cmd)
         if status != 0:
             raise RuntimeError('Error executing: %s' % cmd)
